## cdist-type__consul_watch_key(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__consul_watch_key - manages consul key watches

## 2. DESCRIPTION

Generate and deploy watch definitions of type key for a consul agent. See http://www.consul.io/docs/agent/watches.html for parameter documentation.

## 3. REQUIRED PARAMETERS

handler
  the handler to invoke when the data view updates
key
  the key to watch for changes

## 4. OPTIONAL PARAMETERS

datacenter
  can be provided to override the agent’s default datacenter
state
  if this watch is present or absent. Defaults to present.
token
  can be provided to override the agent’s default ACL token

## 5. EXAMPLES

    __consul_watch_key some-id \
       --key foo/bar/baz \
       --handler /usr/bin/my-key-handler.sh

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__consul_agent(7)
- http://www.consul.io/docs/agent/watches.html

## 7. COPYING

Copyright (C) 2015 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).